@@ -85,8 +85,10 @@ func mustWriteTemplates(jobs []templateJob) {
 		tmplRaw := string(tmplBytes)
 
 		for _, rplString := range job.ReplaceString {
+			rplTitle := cases.Title(language.AmericanEnglish).String(rplString)
+			tmplRaw = strings.ReplaceAll(tmplRaw, "DetectorType_"+rplTitle, "DetectorType_<<.Name>>")
 			tmplRaw = strings.ReplaceAll(tmplRaw, strings.ToLower(rplString), "<<.NameLower>>")
-			tmplRaw = strings.ReplaceAll(tmplRaw, cases.Title(language.AmericanEnglish).String(rplString), "<<.NameTitle>>")
+			tmplRaw = strings.ReplaceAll(tmplRaw, rplTitle, "<<.NameTitle>>")
 			tmplRaw = strings.ReplaceAll(tmplRaw, strings.ToUpper(rplString), "<<.NameUpper>>")
 		}
 
@@ -98,6 +100,7 @@ func mustWriteTemplates(jobs []templateJob) {
 			log.Fatal(err)
 		}
 		err = tmpl.Execute(f, templateData{
+			Name:      *name,
 			NameTitle: nameTitle,
 			NameLower: nameLower,
 			NameUpper: nameUpper,
@@ -109,6 +112,7 @@ func mustWriteTemplates(jobs []templateJob) {
 }
 
 type templateData struct {
+	Name      string
 	NameTitle string
 	NameLower string
 	NameUpper string
