@@ -3,10 +3,11 @@ package mailchimp
 import (
 	"context"
 	"fmt"
-	regexp "github.com/wasilibs/go-re2"
 	"net/http"
 	"strings"
 
+	regexp "github.com/wasilibs/go-re2"
+
 	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/pb/detectorspb"
 
@@ -63,6 +64,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 					s.Verified = true
 				}
 			}
+			s.AnalysisInfo = map[string]string{
+				"key": match,
+			}
 		}
 
 		results = append(results, s)
