@@ -62,12 +62,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 					if err == nil && len(t.Types) > 0 {
 						s1.Verified = true
 					}
-				} else {
-					// This function will check false positives for common test words, but also it will make sure the key appears 'random' enough to be a real key.
-					if detectors.IsKnownFalsePositive(resMatch, detectors.DefaultFalsePositives, true) {
-						continue
-					}
-				}
+				} 
 			}
 		}
 
