@@ -81,11 +81,11 @@ type Source struct {
 // at given increments.
 type persistableCache struct {
 	persistIncrement int
-	cache.Cache
+	cache.Cache[string]
 	*sources.Progress
 }
 
-func newPersistableCache(increment int, cache cache.Cache, p *sources.Progress) *persistableCache {
+func newPersistableCache(increment int, cache cache.Cache[string], p *sources.Progress) *persistableCache {
 	return &persistableCache{
 		persistIncrement: increment,
 		Cache:            cache,
@@ -95,7 +95,7 @@ func newPersistableCache(increment int, cache cache.Cache, p *sources.Progress)
 
 // Set overrides the cache Set method of the cache to enable the persistence
 // of the cache contents the Progress of the source at given increments.
-func (c *persistableCache) Set(key string, val any) {
+func (c *persistableCache) Set(key string, val string) {
 	c.Cache.Set(key, val)
 	if ok, contents := c.shouldPersist(); ok {
 		c.Progress.EncodedResumeInfo = contents
@@ -293,18 +293,18 @@ func (s *Source) Chunks(ctx context.Context, chunksChan chan *sources.Chunk, _ .
 }
 
 func (s *Source) setupCache(ctx context.Context) *persistableCache {
-	var c cache.Cache
+	var c cache.Cache[string]
 	if s.Progress.EncodedResumeInfo != "" {
 		keys := strings.Split(s.Progress.EncodedResumeInfo, ",")
-		entries := make([]memory.CacheEntry, len(keys))
+		entries := make([]memory.CacheEntry[string], len(keys))
 		for i, val := range keys {
-			entries[i] = memory.CacheEntry{Key: val, Value: val}
+			entries[i] = memory.CacheEntry[string]{Key: val, Value: val}
 		}
 
-		c = memory.NewWithData(entries)
+		c = memory.NewWithData[string](entries)
 		ctx.Logger().V(3).Info("Loaded cache", "num_entries", len(entries))
 	} else {
-		c = memory.New()
+		c = memory.New[string]()
 	}
 
 	// TODO (ahrav): Make this configurable via conn.
@@ -312,7 +312,7 @@ func (s *Source) setupCache(ctx context.Context) *persistableCache {
 	return persistCache
 }
 
-func (s *Source) setProgress(ctx context.Context, md5, objName string, cache cache.Cache) {
+func (s *Source) setProgress(ctx context.Context, md5, objName string, cache cache.Cache[string]) {
 	s.mu.Lock()
 	defer s.mu.Unlock()
 
