@@ -654,9 +654,9 @@ func (s *Git) ScanCommits(ctx context.Context, repo *git.Repository, path string
 
 			commitHash := plumbing.NewHash(fullHash)
 			if err := s.handleBinary(ctx, gitDir, reporter, chunkSkel, commitHash, fileName); err != nil {
-				logger.V(1).Info(
+				logger.Error(
+					err,
 					"error handling binary file",
-					"error", err,
 					"filename", fileName,
 					"commit", commitHash,
 					"file", diff.PathB,
@@ -877,7 +877,7 @@ func (s *Git) ScanStaged(ctx context.Context, repo *git.Repository, path string,
 				Verify:         s.verify,
 			}
 			if err := s.handleBinary(ctx, gitDir, reporter, chunkSkel, commitHash, fileName); err != nil {
-				logger.V(1).Info("error handling binary file", "error", err, "filename", fileName)
+				logger.Error(err, "error handling binary file", "filename", fileName)
 			}
 			continue
 		}
@@ -1246,26 +1246,11 @@ func (s *Git) handleBinary(ctx context.Context, gitDir string, reporter sources.
 		return err
 	}
 
-	done := make(chan error, 1)
-	// Read from stdout to prevent the pipe buffer from filling up and causing the command to hang.
-	// This allows us to stream the file contents to the handler.
-	go func() {
-		defer close(done)
-		done <- handlers.HandleFile(ctx, stdout, chunkSkel, reporter, handlers.WithSkipArchives(s.skipArchives))
-	}()
-
-	// Close to signal that we are done writing to the pipe, which allows the reading goroutine to finish.
-	if closeErr := stdout.Close(); closeErr != nil && !errors.Is(closeErr, os.ErrClosed) {
-		ctx.Logger().Error(fmt.Errorf("error closing stdout: %w", closeErr), "closing stdout failed")
+	if err = handlers.HandleFile(ctx, stdout, chunkSkel, reporter, handlers.WithSkipArchives(s.skipArchives)); err != nil {
+		return err
 	}
 
-	if waitErr := cmd.Wait(); waitErr != nil {
-		return fmt.Errorf("error waiting for git cat-file: %w", waitErr)
-	}
-
-	// Wait for the command to finish and the handler to complete.
-	// Capture any error from the file handling process.
-	return <-done
+	return cmd.Wait()
 }
 
 func (s *Git) executeCatFileCmd(cmd *exec.Cmd) (io.ReadCloser, error) {
